@@ -1191,7 +1191,7 @@ class Unit(UnitBase, abstract=True):
         self.log_level = LogLevel.DETACHED
         return self
 
-    def __iter__(self):
+    def __iter__(self) -> Generator[Chunk, None, None]:
         return self
 
     @property
@@ -1432,7 +1432,8 @@ class Unit(UnitBase, abstract=True):
 
         self._target = stream
 
-        def cname(x): return x.lower().replace('-', '')
+        def cname(x: str):
+            return x.lower().replace('-', '')
 
         recode = self.isatty and cname(self.codec) != cname(sys.stdout.encoding)
         chunk = None
@@ -1745,6 +1746,9 @@ class Unit(UnitBase, abstract=True):
         this method will be executed when a class inheriting from `refinery.units.Unit` is defined in
         the current `__main__` module.
         """
+        from refinery.lib import powershell
+        ps1 = powershell.bandaid(cls.codec)
+
         argv = argv if argv is not None else sys.argv[1:]
         start_clock = None
 
@@ -1771,6 +1775,9 @@ class Unit(UnitBase, abstract=True):
                     cls.logger.critical(cls._output(line))
                 return
 
+            if ps1:
+                unit.log_debug(F'applying PowerShell band-aid for: {unit.name}')
+
             try:
                 loglevel = os.environ['REFINERY_VERBOSITY']
             except KeyError:
@@ -1796,7 +1803,7 @@ class Unit(UnitBase, abstract=True):
                 with open(os.devnull, 'wb') if unit.args.devnull else sys.stdout.buffer as output:
                     source | unit | output
             except ArgumentTypeError as E:
-                unit.logger.error(F'delayed argument initialization failed for argument "{E!s}"')
+                unit.logger.error(F'delayed argument initialization failed: {E!s}')
             except KeyboardInterrupt:
                 unit.logger.warning('aborting due to keyboard interrupt')
             except OSError:
